@@ -5,6 +5,17 @@ import matplotlib.pyplot as plt
 class objearth():
     def __init__(self):
         pass
+    def truecolor(self,Dataset,bright=10):
+        self.Dataset = Dataset
+        self.bright  = bright
+        RED    = xarray.where(self.Dataset.red==-9999,numpy.nan,self.Dataset.red)
+        red    = RED.to_numpy()/10000*self.bright
+        BLUE   = xarray.where(self.Dataset.blue==-9999,numpy.nan,self.Dataset.blue)
+        blue   = BLUE.to_numpy()/10000*self.bright
+        GREEN  = xarray.where(self.Dataset.green==-9999,numpy.nan,self.Dataset.green)
+        green  = GREEN.to_numpy()/10000*self.bright
+        rgb    = numpy.stack([red,green,blue],axis=2)
+        return rgb
 
     def clearcloud(self,Dataset0,Dataset1):
         self.Dataset0 = Dataset0
@@ -54,9 +65,8 @@ class objearth():
             secax_x.set_xlabel('longitude')
             secax_y = ax.secondary_yaxis('right',functions=(latitude,axis))
             secax_y.set_ylabel('latitute')
-            plt.grid(color='w', linestyle='-', linewidth=0.1)
+            plt.grid(color='w', linestyle='-', linewidth=0.15)
             plt.show()
-        
         elif type(self.DataArray) == numpy.ndarray:
             if self.lst==True:
                 ymax = 0 ; ymin = self.DataArray.shape[0]
@@ -64,9 +74,13 @@ class objearth():
             else:
                 ymax = self.lst[0] ; ymin = self.lst[1]
                 xmin = self.lst[2] ; xmax = self.lst[3]
-            plt.figure(figsize=(10,10))
+            plt.figure(figsize=(8,8))
             plt.imshow(self.DataArray[ymax:ymin,xmin:xmax],extent=[xmin,xmax,ymin,ymax])
-        
+            plt.xlabel("x axis size")
+            plt.ylabel("y axis size")
+            plt.grid(color='w', linestyle='-', linewidth=0.15)
+            plt.show()
+
         else:
             print("Nonetype :",type(self.DataArray))
             
